@@ -3,9 +3,9 @@
 # by Eriberto
 # Create the manpage using txt2man command.
 
-T2M_DATE="27 Dec 2013"
+T2M_DATE="18 Nov 2016"
 T2M_NAME=chaosreader
-T2M_VERSION=0.94
+T2M_VERSION=0.96
 T2M_LEVEL=1
 T2M_DESC="trace network sessions and export it to html format"
 
